/**
 * Custom converter for the class name
 *
 * @callback classNameConverter
 * @param {string} className - The class name.
 */
export interface ClassArray extends Array<ClassValue> {
}
export interface ClassDictionary {
    [id: string]: any;
}
export declare type ClassValue = string | number | ClassDictionary | ClassArray | undefined | null | boolean;
export declare type ClassNamesFn = (...classes: ClassValue[]) => string;
/**
 * Provides a wrapper around an API similar to [classnames#bind](https://github.com/JedWatson/classnames#alternate-bind-version-for-css-modules)
 * that also supports converting class names before they are looked up in
 * the `classNameMap`.
 *
 * @param {Record<string, string>} localClassNameMap - A map of class names
 * @param {Record<string, string>} globalClassNameMap - A map of class names
 * @param {classNameConverter} classNameConverter - A callback function to convert the class name before being looked up in the class name map
 *
 * @returns {function(...[*]): string} - Returns an API equivalent to [classnames](https://github.com/JedWatson/classnames#usage).
 */
declare function createClassNames(localClassNameMap?: Record<string, string>, globalClassNameMap?: Record<string, string>, classNameConverter?: (className: string) => string): ClassNamesFn;
export default createClassNames;
